import { UpdateReq } from './../wms/materialreq';
import { buildUUID } from '../../../utils/uuid';
import { ApiActionPage } from '../../model/baseModel';
import {
  MaterialInfoListItem,
  MaterialInfoPageParams,
  MaterialInfoPageListGetResultModel,
} from '../model/basModel';
import { genAction, Api, genActionPage } from '../system';
import { defHttp } from '/@/utils/http/axios';
import { useUserStore } from '../../../store/modules/user';

/*
 * 获取物料分页列表
 */
export const getMaterialListByPage = async (params: MaterialInfoPageParams) => {
  let sqlcmd = '';
  if (params?.ITEM_CODE != undefined && params?.ITEM_CODE != '') {
    sqlcmd += "And ITEM_CODE like '%" + params?.ITEM_CODE + "%'";
  }
  const rParams = genActionPage('BAS_ITEM', sqlcmd, params.page, params.pageSize);
  return getMaterialListByPageAsync(rParams);
};
async function getMaterialListByPageAsync(params: ApiActionPage) {
  const data = await defHttp.post<ApiActionPage>(
    { url: Api.EntityPageList, params },
    {
      isTransformResponse: false,
    },
  );
  const model: MaterialInfoPageListGetResultModel = {
    items: data.Data.data,
    total: data.Data.totals,
  };
  return model;
}
//保存物料
export const SaveRegionB = async (params: MaterialInfoListItem, isUpdate: boolean) => {
  let data: any;
  if (isUpdate) {
    data = await defHttp.post(
      { url: Api.UpdateEntity, params: genAction('BAS_ITEM', params) },
      {
        errorMessageMode: 'none',
        isTransformResponse: false,
      },
    );
  } else {
    params.ID = buildUUID(); //生成GUID
    params.CREATE_USER = useUserStore().getUserInfo.username;
    data = await defHttp.post(
      { url: Api.AddEntity, params: genAction('BAS_ITEM', params) },
      {
        errorMessageMode: 'none',
        isTransformResponse: false,
      },
    );
  }
  return data;
};
//保存
export const SaveRegion = async (params: MaterialInfoListItem, isUpdate: boolean) => {
  let data: any;
  if (isUpdate) {
    data = await defHttp.post(
      { url: Api.UpdateEntity, params: genAction('WMS_ITEM', params) },
      {
        errorMessageMode: 'none',
        isTransformResponse: false,
      },
    );
  } else {
    params.ID = buildUUID(); //生成GUID
    params.CREATE_USER = useUserStore().getUserInfo.username;
    data = await defHttp.post(
      { url: Api.AddEntity, params: genAction('WMS_ITEM', params) },
      {
        errorMessageMode: 'none',
        isTransformResponse: false,
      },
    );
  }
  return data;
};
//删除
export const DeleteMaterial = async (params: Recordable) => {
  const usParams = genAction('BAS_ITEM', [params]);
  return await defHttp.post(
    { url: Api.DeleteList, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
};

/*
 * 批量更新产品有效期和预存天数分页列表
 */
export const getMaterialUpdateByPage = async (params: any) => {
  let sqlcmd = '1=1';
  if (params?.ITEM_CODE != undefined && params?.ITEM_CODE != '') {
    sqlcmd += " And ITEM_CODE like '" + params?.ITEM_CODE + "%'";
    const usParams = genAction('BAS_ITEM', {
      QueryAble_T: '',
      where: sqlcmd,
      order: '',
      page: {
        pageAble_T: 'string',
        draw: 1,
        pageIndex: params.page,
        pageSize: params.pageSize,
      },
    });
    return getMaterialUpdateByPageAsync(usParams);
  }
  // if (params?.ITEM_NAME != undefined && params?.ITEM_NAME != '') {
  //   sqlcmd += "And ITEM_NAME like '%" + params?.ITEM_NAME + "%'";
  // }
  // const rParams = genActionPage('BAS_ITEM', sqlcmd, params.page, params.pageSize);
  // return null;
};

async function getMaterialUpdateByPageAsync(params: any) {
  const data = await defHttp.post<any>(
    { url: Api.QueryUrl, params },
    {
      isTransformResponse: false,
    },
  );
  const model: MaterialInfoPageListGetResultModel = {
    items: data.Data.page.data,
    total: data.Data.page.totals,
  };
  return model;
}
export const UpdateTime = async (params: any) => {
  const data = await defHttp.post<any>(
    { url: Api.GetUpdateTime, params },
    {
      isTransformResponse: false,
    },
  );
  return data;
};
